<?php

require("../../include/variables.php");
require("../../include/init.php");

if (!isset($_SESSION['userRole']) || $_SESSION['userRole'] < 50) {
    http_response_code(403);
    die("Vous n'êtes pas autorisé à accéder à cette ressource");
}

require("../../include/main-functions.php");
require("../../include/objects.php");
require("../../include/inputs.php");
require("../../include/panels.php");

$pdo = sqlConnect($sqlDatabaseHost, $sqlDatabaseName, $sqlDatabaseUser, $sqlDatabasePass);

if (isset($_POST['adherent-id'])) {
    $adherentID = (int)$_POST['adherent-id'];
    try {
        // Requête SQL pour déplacer la ligne

        // Préparation de la requêt
            // Valider la transaction
        $sql = "SELECT club FROM adherents WHERE ID = :adherentID";
        $clubIDStmt = $pdo->prepare($sql);
        $clubIDStmt->bindParam(':adherentID', $adherentID, PDO::PARAM_INT);
        $clubIDStmt->execute();
        $clubIDResult = $clubIDStmt->fetchAll(PDO::FETCH_ASSOC);
        $clubFormatted = str_pad($clubIDResult[0]['club'], 2, "0", STR_PAD_LEFT);

        $sql = "SELECT ID FROM adherents WHERE memberid LIKE '59" . $clubFormatted . "%'";
    
        $clubMemberIDStmt = $pdo->prepare($sql);
        $clubMemberIDStmt->execute();
        $clubMemberIDList = $clubMemberIDStmt->fetchAll(PDO::FETCH_ASSOC);
        $clubMemberID = sizeof($clubMemberIDList) + 1;

        $idFormatted = str_pad($clubMemberID, 2, "0", STR_PAD_LEFT);
        $memberID = "59" . $clubFormatted . $idFormatted;

        $sql = "UPDATE adherents SET memberid = :memberID, etape_adhesion = 3 WHERE ID = :adherentID";
        $updateStmt = $pdo->prepare($sql);
        $updateStmt->bindParam(":memberID", $memberID, PDO::PARAM_INT);
        $updateStmt->bindParam(":adherentID", $adherentID, PDO::PARAM_INT);
        if ($updateStmt->execute()) {
            $status = "Adhésion validée";
        } else {
            $status = "Erreur lors de la mise à jour de l'adhérent dans la base";
        }
    } catch (Exception $e) {
        // En cas d'exception, annuler la transaction
        $status = "Erreur SQL";
        error_log("Erreur : " . $e->getMessage());
    }
}

?>

<!DOCTYPE html>
<html lang="fr">

    <head>
        <?php fillHead($rootPageURL, "Admin - " . $pageName, $darkTheme, $lightTheme);?>
        <style>
            table {
                width: 100%;
                text-align: left;
            }
            tr {
                height: 30px;
            }
            th, td {
                border: 1px solid gray;
                padding: 5px;
            }
            .admin-links {
                margin-bottom: 4em;
            }
            .admin-links a {
                margin: 0.5em;
                display: inline-block;
            }
            main .content {
                padding-top: 7em;
            }
        </style>
    </head>

    <body class="body">

        <header>
            <div class="panel-content">
                <?php fillHeader($rootPageURL, $headerTitle, $headerSubtitle, $social);?>
            </div>
        </header>

        <nav>
            <div class="panel-content">
                <?php fillNav($rootPageURL);?>
            </div>
        </nav>

        <main>
            <div class="content">
                <?=$status?>
                <div class="users">
                <?php
                    echo ('<div class="admin-links">');
                    echo ('<a href="index.php" class="button">Utilisateurs</a>');
                    echo ('<a href="adhesions.php" class="button">Demandes d\'adhésion</a>');
                    echo ('<a href="adhesions-non-payees.php" class="button">Adhésions non payées</a>');
                    echo ('<a href="adherents.php" class="button">Adhérents</a>');
                    echo ('<a href="/phpmyadmin" class="button">PHPMyAdmin</a></div>');
                    echo ('<form action="" method="get">');
                    $shapePath = '<path d="M10.25 3.75c-3.59 0-6.5 2.91-6.5 6.5s2.91 6.5 6.5 6.5c1.795 0 3.419-.726 4.596-1.904 1.178-1.177 1.904-2.801 1.904-4.596 0-3.59-2.91-6.5-6.5-6.5zm-8.5 6.5c0-4.694 3.806-8.5 8.5-8.5s8.5 3.806 8.5 8.5c0 1.986-.682 3.815-1.824 5.262l4.781 4.781-1.414 1.414-4.781-4.781c-1.447 1.142-3.276 1.824-5.262 1.824-4.694 0-8.5-3.806-8.5-8.5z"></path>';
                    textInput("text", $shapePath, "search", "Chercher", "");
                    echo ('</form>');

                    $search = isset($_GET['search']) ? '%' . $_GET['search'] . '%' : '%%';

                    $sqlRequest = "SELECT adherents.ID, adherents.firstname, adherents.lastname, adherents.email, adherents.join_date, adherents.userid FROM adherents WHERE (adherents.lastname LIKE :search OR adherents.firstname LIKE :search) AND adherents.etape_adhesion = 2";
                    $request = $pdo->prepare($sqlRequest);
                    $request->bindParam(":search", $search);
                    $request->execute();
                    $result = $request->fetchAll(PDO::FETCH_ASSOC);

                    if ($result) {
                        echo ('<table>');
                        echo ("<tr><th>Prénom Nom</th><th>Email</th><th>Date demande</th><th></th></tr>");
                        foreach($result as $row) {
                            echo ('<tr>');
                            echo ('<form action="#" method="post">');
                            echo ('<td>' . $row['firstname'] . ' ' . $row['lastname'] . '</td><td>' . $row['email'] . '</td><td>' . $row['join_date'] . '</td><td><input type="hidden" name="adherent-id" value="' . $row['ID'] . '"><input type="hidden" name="adhesion-userid" value="' . $row['userid'] . '"><a href="sendmail.php?target=' . $row['email'] . '&type=rappel" class="button">Envoyer un rappel</a><button type="submit" style="margin-left: 1em;">Valider le paiement</button></td>');
                            echo ('</form></tr>');
                        }
                        echo ('</table>');
                    } else {
                        echo ('Aucun utilisateur trouvé.');
                    }
                ?>
                </div>
            </div>
        </main>
        <footer>
            <div class="panel-content">
                <?php fillFooter($footerText);?>
            </div>
        </footer>
    </body>
</html>